"use client"

import type React from "react"

import { useAuth } from "@/context/auth-context"
import { useRouter, usePathname } from "next/navigation"
import { useEffect } from "react"

export default function ProtectedRoute({ children }: { children: React.ReactNode }) {
  const { user, isLoading } = useAuth()
  const router = useRouter()
  const pathname = usePathname()

  // Liste des routes publiques qui ne nécessitent pas d'authentification
  const publicRoutes = ["/landing", "/", "/auth/login", "/auth/register"]

  // Vérifier si le chemin commence par ces préfixes (pour les pages qui doivent être accessibles)
  const isChapterRoute = pathname.startsWith("/chapitres/")
  const isExerciceRoute = pathname.startsWith("/exercices/")
  const isProfileRoute = pathname.startsWith("/profile")
  const isExamenRoute = pathname.startsWith("/examen")

  // Ajouter des logs pour le débogage
  useEffect(() => {
    console.log("ProtectedRoute - État actuel:", {
      isLoading,
      userExists: !!user,
      pathname,
      isPublicRoute: publicRoutes.includes(pathname),
    })

    if (!isLoading && !user && !publicRoutes.includes(pathname)) {
      console.log("Redirection vers /auth/login car l'utilisateur n'est pas connecté")
      router.push("/auth/login")
    }
  }, [user, isLoading, router, pathname])

  if (isLoading) {
    return (
      <div className="min-h-screen flex items-center justify-center">
        <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-route-blue"></div>
      </div>
    )
  }

  if (!user && !publicRoutes.includes(pathname)) {
    return null
  }

  return <>{children}</>
}
